@@ -152,8 +152,12 @@
 #' @export
 workflow_map <- function(object, fn = "tune_grid", verbose = FALSE,
                          seed = sample.int(10^4, 1), ...) {
+  check_wf_set(object)
+
   rlang::arg_match(fn, allowed_fn$func)
   check_object_fn(object, fn)
+  check_bool(verbose)
+  check_number_decimal(seed)
 
   on.exit({
     cols <- tune::get_tune_colors()
@@ -290,7 +294,7 @@ log_progress <- function(verbose, id, res, iter, n, .fn, elapsed) {
     all_null <- isTRUE(all(is.null(unlist(res$.metrics))))
     if (inherits(res, "try-error") || all_null) {
       if (all_null) {
-        res <- collect_notes(res)
+        res <- collect_res_notes(res)
       }
       errors_msg <- gsub("\n", "", as.character(res))
       errors_msg <- gsub("Error : ", "", errors_msg, fixed = TRUE)
@@ -312,3 +316,10 @@ log_progress <- function(verbose, id, res, iter, n, .fn, elapsed) {
 
   invisible(NULL)
 }
+
+collect_res_notes <- function(x, show = 1) {
+   y <- purrr::map_dfr(x$.notes, I)
+   show <- min(show, nrow(y))
+   y <- paste0(y$.notes[1:show])
+   gsub("[\r\n]", "", y)
+}
