@@ -16,7 +16,7 @@ check_metric_results <- function(ind, x, ...) {
     collect_metrics(x, ...) %>%
     dplyr::filter(wflow_id == id_val) %>%
     dplyr::select(dplyr::all_of(cols))
-  dplyr::all_equal(orig, everythng)
+  all.equal(orig, everythng)
 }
 
 # ------------------------------------------------------------------------------
